from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .org.w3.pkg_1999.xlink.actuate_value import ActuateValue
from .org.w3.pkg_1999.xlink.show_value import ShowValue
from .org.w3.pkg_1999.xlink.type_value import TypeValue


@dataclass
class ExtendedBy:
    """
    <div> <h3>Extended-by Model</h3> </div>
    """
    class Meta:
        name = "extended-by"

    assigning_authority: Optional[str] = field(
        default=None,
        metadata={
            "name": "assigning-authority",
            "type": "Attribute",
        }
    )
    designator: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    hreflang: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    vocab: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    vocab_identifier: Optional[str] = field(
        default=None,
        metadata={
            "name": "vocab-identifier",
            "type": "Attribute",
        }
    )
    vocab_term: Optional[str] = field(
        default=None,
        metadata={
            "name": "vocab-term",
            "type": "Attribute",
        }
    )
    vocab_term_identifier: Optional[str] = field(
        default=None,
        metadata={
            "name": "vocab-term-identifier",
            "type": "Attribute",
        }
    )
    actuate: Optional[ActuateValue] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    role: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    show: Optional[ShowValue] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    title: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    type: TypeValue = field(
        init=False,
        default=TypeValue.SIMPLE,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    content: List[object] = field(
        default_factory=list,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
            "mixed": True,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional, Union
from .meta_name import MetaName
from .meta_value import MetaValue
from .org.w3.pkg_1999.xlink.actuate_value import ActuateValue
from .org.w3.pkg_1999.xlink.show_value import ShowValue
from .org.w3.pkg_1999.xlink.type_value import TypeValue
from .org.w3.xml.pkg_1998.namespace.lang_value import LangValue


@dataclass
class CustomMeta:
    """
    <div> <h3>Custom Metadata</h3> </div>
    """
    class Meta:
        name = "custom-meta"

    meta_name: Optional[MetaName] = field(
        default=None,
        metadata={
            "name": "meta-name",
            "type": "Element",
            "required": True,
        }
    )
    meta_value: Optional[MetaValue] = field(
        default=None,
        metadata={
            "name": "meta-value",
            "type": "Element",
            "required": True,
        }
    )
    assigning_authority: Optional[str] = field(
        default=None,
        metadata={
            "name": "assigning-authority",
            "type": "Attribute",
        }
    )
    hreflang: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    specific_use: Optional[str] = field(
        default=None,
        metadata={
            "name": "specific-use",
            "type": "Attribute",
        }
    )
    vocab: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    vocab_identifier: Optional[str] = field(
        default=None,
        metadata={
            "name": "vocab-identifier",
            "type": "Attribute",
        }
    )
    vocab_term: Optional[str] = field(
        default=None,
        metadata={
            "name": "vocab-term",
            "type": "Attribute",
        }
    )
    vocab_term_identifier: Optional[str] = field(
        default=None,
        metadata={
            "name": "vocab-term-identifier",
            "type": "Attribute",
        }
    )
    actuate: Optional[ActuateValue] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    role: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    show: Optional[ShowValue] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    title: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    type: TypeValue = field(
        init=False,
        default=TypeValue.SIMPLE,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    lang: Optional[Union[str, LangValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from .article_id_id_type import ArticleIdIdType


@dataclass
class ArticleId1:
    class Meta:
        name = "ArticleId"

    id_type: ArticleIdIdType = field(
        default=ArticleIdIdType.PUBMED,
        metadata={
            "name": "IdType",
            "type": "Attribute",
            "required": True,
        }
    )
    value: str = field(
        default="",
        metadata={
            "required": True,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional


@dataclass
class XsPattern:
    class Meta:
        name = "xs:pattern"

    value: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "required": True,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Dict, List, Optional

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


@dataclass
class Tendsto:
    class Meta:
        name = "tendsto"
        namespace = "http://www.w3.org/1998/Math/MathML"

    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    encoding: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    definition_url: Optional[str] = field(
        default=None,
        metadata={
            "name": "definitionURL",
            "type": "Attribute",
        }
    )
    type: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List
from .article_1 import Article1


@dataclass
class ArticleSet:
    article: List[Article1] = field(
        default_factory=list,
        metadata={
            "name": "Article",
            "type": "Element",
            "min_occurs": 1,
        }
    )



from enum import Enum


class QuestionQuestionResponseType(Enum):
    ESSAY = "essay"
    FILL_IN_THE_BLANK = "fill-in-the-blank"
    MULTI_SELECT = "multi-select"
    MULTIPLE_CHOICE = "multiple-choice"
    SHORT_ANSWER = "short-answer"
    TRUE_FALSE = "true-false"



from pydantic.dataclasses import dataclass

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


@dataclass
class Sep:
    class Meta:
        name = "sep"
        namespace = "http://www.w3.org/1998/Math/MathML"



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional, Union
from .award_group import AwardGroup
from .org.w3.xml.pkg_1998.namespace.lang_value import LangValue
from .resource_group import ResourceGroup
from .support_description import SupportDescription


@dataclass
class ContributedResourceGroup:
    """
    <div> <h3>Contributed Resource Group</h3> </div>
    """
    class Meta:
        name = "contributed-resource-group"

    award_group: List[AwardGroup] = field(
        default_factory=list,
        metadata={
            "name": "award-group",
            "type": "Element",
        }
    )
    support_description: List[SupportDescription] = field(
        default_factory=list,
        metadata={
            "name": "support-description",
            "type": "Element",
        }
    )
    resource_group: List[ResourceGroup] = field(
        default_factory=list,
        metadata={
            "name": "resource-group",
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    resource_type: Optional[str] = field(
        default=None,
        metadata={
            "name": "resource-type",
            "type": "Attribute",
        }
    )
    specific_use: Optional[str] = field(
        default=None,
        metadata={
            "name": "specific-use",
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    lang: Optional[Union[str, LangValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List
from .suppl_mesh_name import SupplMeshName


@dataclass
class SupplMeshList:
    suppl_mesh_name: List[SupplMeshName] = field(
        default_factory=list,
        metadata={
            "name": "SupplMeshName",
            "type": "Element",
            "min_occurs": 1,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional, Union
from .org.w3.xml.pkg_1998.namespace.lang_value import LangValue


@dataclass
class ResourceId:
    """
    <div> <h3>Resource Identifier</h3> </div>
    """
    class Meta:
        name = "resource-id"

    assigning_authority: Optional[str] = field(
        default=None,
        metadata={
            "name": "assigning-authority",
            "type": "Attribute",
        }
    )
    content_type: Optional[str] = field(
        default=None,
        metadata={
            "name": "content-type",
            "type": "Attribute",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    resource_id_type: Optional[str] = field(
        default=None,
        metadata={
            "name": "resource-id-type",
            "type": "Attribute",
        }
    )
    specific_use: Optional[str] = field(
        default=None,
        metadata={
            "name": "specific-use",
            "type": "Attribute",
        }
    )
    vocab: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    vocab_identifier: Optional[str] = field(
        default=None,
        metadata={
            "name": "vocab-identifier",
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    lang: Optional[Union[str, LangValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    content: List[object] = field(
        default_factory=list,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
            "mixed": True,
        }
    )



from enum import Enum

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


class MtableSide(Enum):
    LEFT = "left"
    RIGHT = "right"
    LEFTOVERLAP = "leftoverlap"
    RIGHTOVERLAP = "rightoverlap"



from enum import Enum


class CommentsCorrectionsRefType(Enum):
    ASSOCIATED_DATASET = "AssociatedDataset"
    ASSOCIATED_PUBLICATION = "AssociatedPublication"
    COMMENT_IN = "CommentIn"
    COMMENT_ON = "CommentOn"
    CORRECTEDAND_REPUBLISHED_IN = "CorrectedandRepublishedIn"
    CORRECTEDAND_REPUBLISHED_FROM = "CorrectedandRepublishedFrom"
    ERRATUM_IN = "ErratumIn"
    ERRATUM_FOR = "ErratumFor"
    EXPRESSION_OF_CONCERN_IN = "ExpressionOfConcernIn"
    EXPRESSION_OF_CONCERN_FOR = "ExpressionOfConcernFor"
    REPUBLISHED_IN = "RepublishedIn"
    REPUBLISHED_FROM = "RepublishedFrom"
    RETRACTEDAND_REPUBLISHED_IN = "RetractedandRepublishedIn"
    RETRACTEDAND_REPUBLISHED_FROM = "RetractedandRepublishedFrom"
    RETRACTION_IN = "RetractionIn"
    RETRACTION_OF = "RetractionOf"
    UPDATE_IN = "UpdateIn"
    UPDATE_OF = "UpdateOf"
    SUMMARY_FOR_PATIENTS_IN = "SummaryForPatientsIn"
    ORIGINAL_REPORT_IN = "OriginalReportIn"
    REPRINT_IN = "ReprintIn"
    REPRINT_OF = "ReprintOf"
    CITES = "Cites"



from enum import Enum


class TableFrame(Enum):
    ABOVE = "above"
    BELOW = "below"
    BORDER = "border"
    BOX = "box"
    HSIDES = "hsides"
    LHS = "lhs"
    RHS = "rhs"
    VOID = "void"
    VSIDES = "vsides"



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional, Union
from .access_date import OpenAccess
from .award_group import AwardGroup
from .funding_statement import FundingStatement
from .org.w3.xml.pkg_1998.namespace.lang_value import LangValue


@dataclass
class FundingGroup:
    """
    <div> <h3>Funding Group</h3> </div>
    """
    class Meta:
        name = "funding-group"

    award_group: List[AwardGroup] = field(
        default_factory=list,
        metadata={
            "name": "award-group",
            "type": "Element",
        }
    )
    funding_statement: List[FundingStatement] = field(
        default_factory=list,
        metadata={
            "name": "funding-statement",
            "type": "Element",
        }
    )
    open_access: List[OpenAccess] = field(
        default_factory=list,
        metadata={
            "name": "open-access",
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    specific_use: Optional[str] = field(
        default=None,
        metadata={
            "name": "specific-use",
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    lang: Optional[Union[str, LangValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List
from .section import Section


@dataclass
class Sections:
    section: List[Section] = field(
        default_factory=list,
        metadata={
            "name": "Section",
            "type": "Element",
            "min_occurs": 1,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .access_date import (
    Fn,
    Label,
    P,
    Title,
    X,
)
from .corresp import Corresp


@dataclass
class AuthorNotes:
    """
    <div> <h3>Author Note Group</h3> </div>
    """
    class Meta:
        name = "author-notes"

    label: Optional[Label] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    title: Optional[Title] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    corresp: List[Corresp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fn: List[Fn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    p: List[P] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    x: List[X] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    rid: List[str] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    specific_use: Optional[str] = field(
        default=None,
        metadata={
            "name": "specific-use",
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional
from .article_id_list import ArticleIdList
from .citation import Citation


@dataclass
class Reference:
    citation: Optional[Citation] = field(
        default=None,
        metadata={
            "name": "Citation",
            "type": "Element",
            "required": True,
        }
    )
    article_id_list: Optional[ArticleIdList] = field(
        default=None,
        metadata={
            "name": "ArticleIdList",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List
from .data_bank import DataBank
from .data_bank_list_complete_yn import DataBankListCompleteYn


@dataclass
class DataBankList:
    complete_yn: DataBankListCompleteYn = field(
        default=DataBankListCompleteYn.Y,
        metadata={
            "name": "CompleteYN",
            "type": "Attribute",
            "required": True,
        }
    )
    data_bank: List[DataBank] = field(
        default_factory=list,
        metadata={
            "name": "DataBank",
            "type": "Element",
            "min_occurs": 1,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .type_value import TypeValue

__NAMESPACE__ = "http://www.w3.org/1999/xlink"


@dataclass
class ResourceType:
    class Meta:
        name = "resourceType"

    type: TypeValue = field(
        init=False,
        default=TypeValue.RESOURCE,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
            "required": True,
        }
    )
    role: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    title: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    label: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    content: List[object] = field(
        default_factory=list,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
            "mixed": True,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .abstract_text import AbstractText


@dataclass
class Abstract1:
    class Meta:
        name = "Abstract"

    abstract_text: List[AbstractText] = field(
        default_factory=list,
        metadata={
            "name": "AbstractText",
            "type": "Element",
            "min_occurs": 1,
        }
    )
    copyright_information: Optional[str] = field(
        default=None,
        metadata={
            "name": "CopyrightInformation",
            "type": "Element",
        }
    )



from dataclasses import field
from decimal import Decimal
from pydantic.dataclasses import dataclass
from typing import Dict, List, Optional, Union
from .abs import Abs
from .and_mod import And
from .annotation import Annotation
from .approx import Approx
from .arccos import Arccos
from .arccosh import Arccosh
from .arccot import Arccot
from .arccoth import Arccoth
from .arccsc import Arccsc
from .arccsch import Arccsch
from .arcsec import Arcsec
from .arcsech import Arcsech
from .arcsin import Arcsin
from .arcsinh import Arcsinh
from .arctan import Arctan
from .arctanh import Arctanh
from .arg import Arg
from .card import Card
from .cartesianproduct import Cartesianproduct
from .cbytes import Cbytes
from .ceiling import Ceiling
from .codomain import Codomain
from .columnalignstyle import Columnalignstyle
from .complexes import Complexes
from .compose import Compose
from .condition import (
    AnnotationXml,
    Apply,
    Bind,
    Cerror,
    Ci,
    Cn,
    Csymbol,
    Declare,
    Fn,
    ListType,
    Maction,
    Menclose,
    Merror,
    Mfenced,
    Mfrac,
    Mlongdiv,
    Mmultiscripts,
    Mover,
    Mpadded,
    Mphantom,
    Mroot,
    Mrow,
    Msqrt,
    Mstack,
    Mstyle,
    Msub,
    Msubsup,
    Msup,
    Munder,
    Munderover,
    Piecewise,
    Reln,
    Set,
)
from .conjugate import Conjugate
from .cos import Cos
from .cosh import Cosh
from .cot import Cot
from .coth import Coth
from .cs import Cs
from .csc import Csc
from .csch import Csch
from .curl import Curl
from .determinant import Determinant
from .diff import Diff
from .divergence import Divergence
from .divide import Divide
from .domain import Domain
from .emptyset import Emptyset
from .eq import Eq
from .equivalent import Equivalent
from .eulergamma import Eulergamma
from .exists import Exists
from .exp import Exp
from .exponentiale import Exponentiale
from .factorial import Factorial
from .factorof import Factorof
from .false import FalseType
from .floor import Floor
from .forall import Forall
from .gcd import Gcd
from .geq import Geq
from .grad import Grad
from .gt import Gt
from .ident import Ident
from .image import Image
from .imaginary import Imaginary
from .imaginaryi import Imaginaryi
from .implies import Implies
from .in_mod import In
from .infinity import Infinity
from .int_mod import Int
from .integers import Integers
from .intersect import Intersect
from .interval import Interval
from .inverse import Inverse
from .lambda_mod import Lambda
from .laplacian import Laplacian
from .lcm import Lcm
from .leq import Leq
from .limit import Limit
from .linestyle import Linestyle
from .ln import Ln
from .log import Log
from .lt import Lt
from .maligngroup import Maligngroup
from .malignmark import Malignmark
from .math_accent import MathAccent
from .math_accentunder import MathAccentunder
from .math_align import MathAlign
from .math_bevelled import MathBevelled
from .math_charalign import MathCharalign
from .math_denomalign import MathDenomalign
from .math_dir import MathDir
from .math_display import MathDisplay
from .math_displaystyle import MathDisplaystyle
from .math_edge import MathEdge
from .math_equalcolumns import MathEqualcolumns
from .math_equalrows import MathEqualrows
from .math_fence import MathFence
from .math_form import MathForm
from .math_indentalign import MathIndentalign
from .math_indentalignfirst import MathIndentalignfirst
from .math_indentalignlast import MathIndentalignlast
from .math_infixlinebreakstyle import MathInfixlinebreakstyle
from .math_largeop import MathLargeop
from .math_linebreak import MathLinebreak
from .math_linebreakstyle import MathLinebreakstyle
from .math_location import MathLocation
from .math_longdivstyle import MathLongdivstyle
from .math_mathvariant import MathMathvariant
from .math_movablelimits import MathMovablelimits
from .math_numalign import MathNumalign
from .math_overflow import MathOverflow
from .math_separator import MathSeparator
from .math_side import MathSide
from .math_stackalign import MathStackalign
from .math_stretchy import MathStretchy
from .math_symmetric import MathSymmetric
from .math_value import MathValue
from .matrix import Matrix
from .matrixrow import Matrixrow
from .max import Max
from .mean import Mean
from .median import Median
from .mi import Mi
from .min import Min
from .minus import Minus
from .mn import Mn
from .mo import Mo
from .mode import Mode
from .moment import Moment
from .ms import Ms
from .mspace import Mspace
from .mtable import Mtable
from .mtext import Mtext
from .naturalnumbers import Naturalnumbers
from .neq import Neq
from .not_mod import Not
from .notanumber import Notanumber
from .notin import Notin
from .notprsubset import Notprsubset
from .notsubset import Notsubset
from .or_mod import Or
from .outerproduct import Outerproduct
from .partialdiff import Partialdiff
from .pi import Pi
from .plus import Plus
from .power import Power
from .primes import Primes
from .product import Product
from .prsubset import Prsubset
from .quotient import Quotient
from .rationals import Rationals
from .real import Real
from .reals import Reals
from .rem import Rem
from .root import Root
from .scalarproduct import Scalarproduct
from .sdev import Sdev
from .sec import Sec
from .sech import Sech
from .selector import Selector
from .setdiff import Setdiff
from .share import Share
from .sin import Sin
from .sinh import Sinh
from .subset import Subset
from .sum import Sum
from .tan import Tan
from .tanh import Tanh
from .tendsto import Tendsto
from .times import Times
from .transpose import Transpose
from .true import TrueType
from .union import UnionType
from .variance import Variance
from .vector import Vector
from .vectorproduct import Vectorproduct
from .verticalalign import Verticalalign
from .xor import Xor

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


@dataclass
class Math:
    class Meta:
        name = "math"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: List[Apply] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    bind: List[Bind] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ci: List[Ci] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cn: List[Cn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csymbol: List[Csymbol] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cerror: List[Cerror] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    piecewise: List[Piecewise] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    declare: List[Declare] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fn: List[Fn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reln: List[Reln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    maction: List[Maction] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mlongdiv: List[Mlongdiv] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mstack: List[Mstack] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mtable: List[Mtable] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mmultiscripts: List[Mmultiscripts] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    munderover: List[Munderover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mover: List[Mover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    munder: List[Munder] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msubsup: List[Msubsup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msup: List[Msup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msub: List[Msub] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    menclose: List[Menclose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mfenced: List[Mfenced] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mphantom: List[Mphantom] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mpadded: List[Mpadded] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    merror: List[Merror] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mstyle: List[Mstyle] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mroot: List[Mroot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msqrt: List[Msqrt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mfrac: List[Mfrac] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mrow: List[Mrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    maligngroup: List[Maligngroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    malignmark: List[Malignmark] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ms: List[Ms] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mspace: List[Mspace] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mtext: List[Mtext] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mo: List[Mo] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mn: List[Mn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mi: List[Mi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    semantics: List["Math.Semantics"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MathValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    scriptlevel: Optional[int] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    displaystyle: Optional[MathDisplaystyle] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    scriptsizemultiplier: Optional[Decimal] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    scriptminsize: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    infixlinebreakstyle: Optional[MathInfixlinebreakstyle] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    decimalpoint: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*\S\s*",
        }
    )
    accent: Optional[MathAccent] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    accentunder: Optional[MathAccentunder] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    align: Optional[MathAlign] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    alignmentscope: List[MathValue] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    bevelled: Optional[MathBevelled] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    charalign: Optional[MathCharalign] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    charspacing: Optional[Union[str, MathValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    close: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    columnalign: List[Columnalignstyle] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    columnlines: List[Linestyle] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    columnspacing: List[str] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
            "tokens": True,
        }
    )
    columnspan: Optional[int] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    columnwidth: List[MathValue] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    crossout: List[MathValue] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    denomalign: Optional[MathDenomalign] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    depth: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    dir: Optional[MathDir] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    edge: Optional[MathEdge] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    equalcolumns: Optional[MathEqualcolumns] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    equalrows: Optional[MathEqualrows] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    fence: Optional[MathFence] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    form: Optional[MathForm] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    frame: Optional[Linestyle] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    framespacing: List[object] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "length": 2,
            "tokens": True,
        }
    )
    groupalign: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"(\s*\{\s*(left|center|right|decimalpoint)(\s+(left|center|right|decimalpoint))*\})*\s*",
        }
    )
    height: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    indentalign: Optional[MathIndentalign] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    indentalignfirst: Optional[MathIndentalignfirst] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    indentalignlast: Optional[MathIndentalignlast] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    indentshift: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    indentshiftfirst: Optional[Union[str, MathValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    indentshiftlast: Optional[Union[str, MathValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    indenttarget: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    largeop: Optional[MathLargeop] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    leftoverhang: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    length: Optional[int] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    linebreak: Optional[MathLinebreak] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    linebreakmultchar: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    linebreakstyle: Optional[MathLinebreakstyle] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    lineleading: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    linethickness: Optional[Union[str, MathValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    location: Optional[MathLocation] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    longdivstyle: Optional[MathLongdivstyle] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    lquote: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    lspace: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    mathsize: Optional[Union[str, MathValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    mathvariant: Optional[MathMathvariant] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    maxsize: Optional[Union[str, MathValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    minlabelspacing: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    minsize: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    movablelimits: Optional[MathMovablelimits] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    mslinethickness: Optional[Union[str, MathValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    notation: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    numalign: Optional[MathNumalign] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    open: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    position: Optional[int] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    rightoverhang: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    rowalign: List[Verticalalign] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    rowlines: List[Linestyle] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    rowspacing: List[str] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
            "tokens": True,
        }
    )
    rowspan: Optional[int] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    rquote: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    rspace: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    selection: Optional[int] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    separator: Optional[MathSeparator] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    separators: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    shift: Optional[int] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    side: Optional[MathSide] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    stackalign: Optional[MathStackalign] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    stretchy: Optional[MathStretchy] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    subscriptshift: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    superscriptshift: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    symmetric: Optional[MathSymmetric] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    valign: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    width: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    display: Optional[MathDisplay] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    maxwidth: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    overflow: Optional[MathOverflow] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    altimg: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    altimg_width: Optional[str] = field(
        default=None,
        metadata={
            "name": "altimg-width",
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    altimg_height: Optional[str] = field(
        default=None,
        metadata={
            "name": "altimg-height",
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    altimg_valign: Optional[Union[str, MathValue]] = field(
        default=None,
        metadata={
            "name": "altimg-valign",
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    alttext: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    cdgroup: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    mode_attribute: Optional[str] = field(
        default=None,
        metadata={
            "name": "mode",
            "type": "Attribute",
        }
    )
    macros: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )

    @dataclass
    class Semantics:
        apply: Optional[Apply] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        bind: Optional[Bind] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ci: Optional[Ci] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cn: Optional[Cn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csymbol: Optional[Csymbol] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cbytes: Optional[Cbytes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cerror: Optional[Cerror] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cs: Optional[Cs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        share: Optional[Share] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        piecewise: Optional[Piecewise] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        declare: Optional[Declare] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        fn: Optional[Fn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reln: Optional[Reln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        interval: Optional[Interval] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        moment: Optional[Moment] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        log: Optional[Log] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ln: Optional[Ln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        image: Optional[Image] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        codomain: Optional[Codomain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        domain: Optional[Domain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ident: Optional[Ident] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        inverse: Optional[Inverse] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lambda_value: Optional[Lambda] = field(
            default=None,
            metadata={
                "name": "lambda",
                "type": "Element",
            }
        )
        compose: Optional[Compose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        quotient: Optional[Quotient] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divide: Optional[Divide] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        minus: Optional[Minus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        power: Optional[Power] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rem: Optional[Rem] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        root: Optional[Root] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorial: Optional[Factorial] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        abs: Optional[Abs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        conjugate: Optional[Conjugate] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arg: Optional[Arg] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        real: Optional[Real] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginary: Optional[Imaginary] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        floor: Optional[Floor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ceiling: Optional[Ceiling] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exp: Optional[Exp] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        min: Optional[Min] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        max: Optional[Max] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lcm: Optional[Lcm] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gcd: Optional[Gcd] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        times: Optional[Times] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        plus: Optional[Plus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        xor: Optional[Xor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        or_value: Optional[Or] = field(
            default=None,
            metadata={
                "name": "or",
                "type": "Element",
            }
        )
        and_value: Optional[And] = field(
            default=None,
            metadata={
                "name": "and",
                "type": "Element",
            }
        )
        not_value: Optional[Not] = field(
            default=None,
            metadata={
                "name": "not",
                "type": "Element",
            }
        )
        equivalent: Optional[Equivalent] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        implies: Optional[Implies] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exists: Optional[Exists] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        forall: Optional[Forall] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        leq: Optional[Leq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        geq: Optional[Geq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lt: Optional[Lt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gt: Optional[Gt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eq: Optional[Eq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tendsto: Optional[Tendsto] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorof: Optional[Factorof] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        approx: Optional[Approx] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        neq: Optional[Neq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        int_value: Optional[Int] = field(
            default=None,
            metadata={
                "name": "int",
                "type": "Element",
            }
        )
        diff: Optional[Diff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        partialdiff: Optional[Partialdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        laplacian: Optional[Laplacian] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        curl: Optional[Curl] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        grad: Optional[Grad] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divergence: Optional[Divergence] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        list_value: Optional[ListType] = field(
            default=None,
            metadata={
                "name": "list",
                "type": "Element",
            }
        )
        set: Optional[Set] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cartesianproduct: Optional[Cartesianproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        intersect: Optional[Intersect] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        union: Optional[UnionType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        setdiff: Optional[Setdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notprsubset: Optional[Notprsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notsubset: Optional[Notsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notin: Optional[Notin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        in_value: Optional[In] = field(
            default=None,
            metadata={
                "name": "in",
                "type": "Element",
            }
        )
        prsubset: Optional[Prsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        subset: Optional[Subset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        card: Optional[Card] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sum: Optional[Sum] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        product: Optional[Product] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        limit: Optional[Limit] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctanh: Optional[Arctanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsinh: Optional[Arcsinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsech: Optional[Arcsech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsec: Optional[Arcsec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsch: Optional[Arccsch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsc: Optional[Arccsc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccoth: Optional[Arccoth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccot: Optional[Arccot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccosh: Optional[Arccosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctan: Optional[Arctan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccos: Optional[Arccos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsin: Optional[Arcsin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        coth: Optional[Coth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csch: Optional[Csch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sech: Optional[Sech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tanh: Optional[Tanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cosh: Optional[Cosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sinh: Optional[Sinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cot: Optional[Cot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csc: Optional[Csc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sec: Optional[Sec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tan: Optional[Tan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cos: Optional[Cos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sin: Optional[Sin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mode: Optional[Mode] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        median: Optional[Median] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        variance: Optional[Variance] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sdev: Optional[Sdev] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mean: Optional[Mean] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrixrow: Optional[Matrixrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrix: Optional[Matrix] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vector: Optional[Vector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        transpose: Optional[Transpose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        determinant: Optional[Determinant] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        selector: Optional[Selector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        outerproduct: Optional[Outerproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        scalarproduct: Optional[Scalarproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vectorproduct: Optional[Vectorproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        emptyset: Optional[Emptyset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        primes: Optional[Primes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        complexes: Optional[Complexes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        naturalnumbers: Optional[Naturalnumbers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rationals: Optional[Rationals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reals: Optional[Reals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        integers: Optional[Integers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        infinity: Optional[Infinity] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eulergamma: Optional[Eulergamma] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        pi: Optional[Pi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        false: Optional[FalseType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        true: Optional[TrueType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notanumber: Optional[Notanumber] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginaryi: Optional[Imaginaryi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exponentiale: Optional[Exponentiale] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maction: Optional[Maction] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mlongdiv: Optional[Mlongdiv] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstack: Optional[Mstack] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtable: Optional[Mtable] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mmultiscripts: Optional[Mmultiscripts] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munderover: Optional[Munderover] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mover: Optional[Mover] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munder: Optional[Munder] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msubsup: Optional[Msubsup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msup: Optional[Msup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msub: Optional[Msub] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        menclose: Optional[Menclose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfenced: Optional[Mfenced] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mphantom: Optional[Mphantom] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mpadded: Optional[Mpadded] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        merror: Optional[Merror] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstyle: Optional[Mstyle] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mroot: Optional[Mroot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msqrt: Optional[Msqrt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfrac: Optional[Mfrac] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mrow: Optional[Mrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maligngroup: Optional[Maligngroup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        malignmark: Optional[Malignmark] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ms: Optional[Ms] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mspace: Optional[Mspace] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtext: Optional[Mtext] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mo: Optional[Mo] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mn: Optional[Mn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mi: Optional[Mi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        semantics: Optional["Math.Semantics"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        annotation: List[Annotation] = field(
            default_factory=list,
            metadata={
                "type": "Element",
            }
        )
        annotation_xml: List[AnnotationXml] = field(
            default_factory=list,
            metadata={
                "name": "annotation-xml",
                "type": "Element",
            }
        )
        id: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        xref: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        class_value: List[str] = field(
            default_factory=list,
            metadata={
                "name": "class",
                "type": "Attribute",
                "tokens": True,
            }
        )
        style: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        href: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other_attributes: Dict[str, str] = field(
            default_factory=dict,
            metadata={
                "type": "Attributes",
                "namespace": "##other",
            }
        )
        encoding: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        definition_url: Optional[str] = field(
            default=None,
            metadata={
                "name": "definitionURL",
                "type": "Attribute",
            }
        )
        cd: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        name: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional


@dataclass
class ItemList:
    list_type: Optional[str] = field(
        default=None,
        metadata={
            "name": "ListType",
            "type": "Attribute",
            "required": True,
        }
    )
    item: List[str] = field(
        default_factory=list,
        metadata={
            "name": "Item",
            "type": "Element",
            "min_occurs": 1,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional, Union
from .access_date import (
    StringDate,
    X,
)
from .day import Day
from .era import Era
from .month import Month
from .org.w3.xml.pkg_1998.namespace.lang_value import LangValue
from .season import Season
from .year import Year


@dataclass
class PubDate2:
    """
    <div> <h3>Publication Date</h3> </div>
    """
    class Meta:
        name = "pub-date"

    day: List[Day] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    era: List[Era] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    month: List[Month] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    season: List[Season] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    year: List[Year] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    string_date: List[StringDate] = field(
        default_factory=list,
        metadata={
            "name": "string-date",
            "type": "Element",
        }
    )
    x: List[X] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    assigning_authority: Optional[str] = field(
        default=None,
        metadata={
            "name": "assigning-authority",
            "type": "Attribute",
        }
    )
    calendar: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    date_type: Optional[str] = field(
        default=None,
        metadata={
            "name": "date-type",
            "type": "Attribute",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    iso_8601_date: Optional[str] = field(
        default=None,
        metadata={
            "name": "iso-8601-date",
            "type": "Attribute",
        }
    )
    pub_type: Optional[str] = field(
        default=None,
        metadata={
            "name": "pub-type",
            "type": "Attribute",
        }
    )
    publication_format: Optional[str] = field(
        default=None,
        metadata={
            "name": "publication-format",
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    lang: Optional[Union[str, LangValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List
from .pubmed_book_article import PubmedBookArticle


@dataclass
class PubmedBookArticleSet:
    pubmed_book_article: List[PubmedBookArticle] = field(
        default_factory=list,
        metadata={
            "name": "PubmedBookArticle",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional
from .journal_issue_cited_medium import JournalIssueCitedMedium
from .pub_date_1 import PubDate1


@dataclass
class JournalIssue:
    cited_medium: Optional[JournalIssueCitedMedium] = field(
        default=None,
        metadata={
            "name": "CitedMedium",
            "type": "Attribute",
            "required": True,
        }
    )
    volume: Optional[str] = field(
        default=None,
        metadata={
            "name": "Volume",
            "type": "Element",
        }
    )
    issue: Optional[str] = field(
        default=None,
        metadata={
            "name": "Issue",
            "type": "Element",
        }
    )
    pub_date: Optional[PubDate1] = field(
        default=None,
        metadata={
            "name": "PubDate",
            "type": "Element",
            "required": True,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional
from .issn_1 import Issn1
from .journal_issue import JournalIssue


@dataclass
class Journal:
    issn: Optional[Issn1] = field(
        default=None,
        metadata={
            "name": "ISSN",
            "type": "Element",
        }
    )
    journal_issue: Optional[JournalIssue] = field(
        default=None,
        metadata={
            "name": "JournalIssue",
            "type": "Element",
            "required": True,
        }
    )
    title: Optional[str] = field(
        default=None,
        metadata={
            "name": "Title",
            "type": "Element",
        }
    )
    isoabbreviation: Optional[str] = field(
        default=None,
        metadata={
            "name": "ISOAbbreviation",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional, Union
from .access_date import (
    Name,
    NameAlternatives,
    StringName,
)
from .contrib_id import ContribId
from .org.w3.xml.pkg_1998.namespace.lang_value import LangValue


@dataclass
class PrincipalInvestigator:
    """
    <div> <h3>Principal Investigator Recipient</h3> </div>
    """
    class Meta:
        name = "principal-investigator"

    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    specific_use: Optional[str] = field(
        default=None,
        metadata={
            "name": "specific-use",
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    lang: Optional[Union[str, LangValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    content: List[object] = field(
        default_factory=list,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
            "mixed": True,
            "choices": (
                {
                    "name": "contrib-id",
                    "type": ContribId,
                },
                {
                    "name": "name",
                    "type": Name,
                },
                {
                    "name": "name-alternatives",
                    "type": NameAlternatives,
                },
                {
                    "name": "string-name",
                    "type": StringName,
                },
            ),
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .custom_meta_group import CustomMetaGroup
from .extended_by import ExtendedBy
from .processing_meta_base_tagset import ProcessingMetaBaseTagset
from .processing_meta_mathml_version import ProcessingMetaMathmlVersion
from .processing_meta_table_model import ProcessingMetaTableModel
from .processing_meta_tagset_family import ProcessingMetaTagsetFamily
from .restricted_by import RestrictedBy


@dataclass
class ProcessingMeta:
    """
    <div> <h3>Processing Metadata Model</h3> </div>
    """
    class Meta:
        name = "processing-meta"

    restricted_by: List[RestrictedBy] = field(
        default_factory=list,
        metadata={
            "name": "restricted-by",
            "type": "Element",
        }
    )
    extended_by: List[ExtendedBy] = field(
        default_factory=list,
        metadata={
            "name": "extended-by",
            "type": "Element",
        }
    )
    custom_meta_group: List[CustomMetaGroup] = field(
        default_factory=list,
        metadata={
            "name": "custom-meta-group",
            "type": "Element",
        }
    )
    base_tagset: Optional[ProcessingMetaBaseTagset] = field(
        default=None,
        metadata={
            "name": "base-tagset",
            "type": "Attribute",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    math_representation: List[str] = field(
        default_factory=list,
        metadata={
            "name": "math-representation",
            "type": "Attribute",
            "tokens": True,
        }
    )
    mathml_version: Optional[ProcessingMetaMathmlVersion] = field(
        default=None,
        metadata={
            "name": "mathml-version",
            "type": "Attribute",
        }
    )
    table_model: Optional[ProcessingMetaTableModel] = field(
        default=None,
        metadata={
            "name": "table-model",
            "type": "Attribute",
        }
    )
    tagset_family: Optional[ProcessingMetaTagsetFamily] = field(
        default=None,
        metadata={
            "name": "tagset-family",
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from enum import Enum

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


class MlabeledtrRowalign(Enum):
    TOP = "top"
    BOTTOM = "bottom"
    CENTER = "center"
    BASELINE = "baseline"
    AXIS = "axis"



from .actuate_value import ActuateValue
from .arc_type import ArcType
from .extended import Extended
from .locator_type import LocatorType
from .resource_type import ResourceType
from .show_value import ShowValue
from .simple import Simple
from .title_elt_type import TitleEltType
from .type_value import TypeValue

__all__ = [
    "ActuateValue",
    "ArcType",
    "Extended",
    "LocatorType",
    "ResourceType",
    "ShowValue",
    "Simple",
    "TitleEltType",
    "TypeValue",
]



from dataclasses import field
from pydantic.dataclasses import dataclass
from .general_note_owner import GeneralNoteOwner


@dataclass
class GeneralNote:
    owner: GeneralNoteOwner = field(
        default=GeneralNoteOwner.NLM,
        metadata={
            "name": "Owner",
            "type": "Attribute",
            "required": True,
        }
    )
    value: str = field(
        default="",
        metadata={
            "required": True,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional
from .col_align import ColAlign
from .col_valign import ColValign


@dataclass
class Col:
    class Meta:
        name = "col"

    align: Optional[ColAlign] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    char: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    charoff: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    content_type: Optional[str] = field(
        default=None,
        metadata={
            "name": "content-type",
            "type": "Attribute",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    span: str = field(
        default="1",
        metadata={
            "type": "Attribute",
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    valign: Optional[ColValign] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    width: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



__version__ = "0.1.1"

from pathlib import Path
from typing import Union

from xsdata_pydantic.bindings import XmlParser

from .models.article_2 import Article2 as PMCArticle
from .models.pubmed_article_set import PubmedArticleSet


def parse_pubmed_xml(xml: Union[Path, str]) -> Union[PMCArticle, PubmedArticleSet]:
    parser = XmlParser()

    try:
        result = parser.parse(xml, PMCArticle)
    except:
        result = parser.parse(xml, PubmedArticleSet)

    return result



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .abbrev_journal_title import AbbrevJournalTitle
from .journal_subtitle import JournalSubtitle
from .journal_title import JournalTitle
from .trans_title_group import TransTitleGroup


@dataclass
class JournalTitleGroup:
    """
    <div> <h3>Journal Title Group</h3> </div>
    """
    class Meta:
        name = "journal-title-group"

    journal_title: List[JournalTitle] = field(
        default_factory=list,
        metadata={
            "name": "journal-title",
            "type": "Element",
        }
    )
    journal_subtitle: List[JournalSubtitle] = field(
        default_factory=list,
        metadata={
            "name": "journal-subtitle",
            "type": "Element",
        }
    )
    trans_title_group: List[TransTitleGroup] = field(
        default_factory=list,
        metadata={
            "name": "trans-title-group",
            "type": "Element",
        }
    )
    abbrev_journal_title: List[AbbrevJournalTitle] = field(
        default_factory=list,
        metadata={
            "name": "abbrev-journal-title",
            "type": "Element",
        }
    )
    content_type: Optional[str] = field(
        default=None,
        metadata={
            "name": "content-type",
            "type": "Attribute",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional
from .type_value import TypeValue

__NAMESPACE__ = "http://www.w3.org/1999/xlink"


@dataclass
class Extended:
    """Intended for use as the type of user-declared elements to make them extended
    links.

    Note that the elements referenced in the content model are all
    abstract. The intention is that by simply declaring elements with
    these as their substitutionGroup, all the right things will happen.
    """
    class Meta:
        name = "extended"

    type: TypeValue = field(
        init=False,
        default=TypeValue.EXTENDED,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
            "required": True,
        }
    )
    role: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    title: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional


@dataclass
class UnderlineStart:
    """
    <div> <h3>Underline Start</h3> </div>
    """
    class Meta:
        name = "underline-start"

    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "required": True,
        }
    )
    specific_use: Optional[str] = field(
        default=None,
        metadata={
            "name": "specific-use",
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from .first_page_lzero import FirstPageLzero


@dataclass
class FirstPage:
    lzero: FirstPageLzero = field(
        default=FirstPageLzero.DELETE,
        metadata={
            "name": "LZero",
            "type": "Attribute",
            "required": True,
        }
    )
    value: str = field(
        default="",
        metadata={
            "required": True,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from .replaces_id_type import ReplacesIdType


@dataclass
class Replaces:
    id_type: ReplacesIdType = field(
        default=ReplacesIdType.PUBMED,
        metadata={
            "name": "IdType",
            "type": "Attribute",
            "required": True,
        }
    )
    value: str = field(
        default="",
        metadata={
            "required": True,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List
from .grant import Grant
from .grant_list_complete_yn import GrantListCompleteYn


@dataclass
class GrantList:
    complete_yn: GrantListCompleteYn = field(
        default=GrantListCompleteYn.Y,
        metadata={
            "name": "CompleteYN",
            "type": "Attribute",
            "required": True,
        }
    )
    grant: List[Grant] = field(
        default_factory=list,
        metadata={
            "name": "Grant",
            "type": "Element",
            "min_occurs": 1,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .event import Event


@dataclass
class PubHistory:
    """
    <div> <h3>Publication History</h3> </div>
    """
    class Meta:
        name = "pub-history"

    event: List[Event] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List
from .personal_name_subject import PersonalNameSubject


@dataclass
class PersonalNameSubjectList:
    personal_name_subject: List[PersonalNameSubject] = field(
        default_factory=list,
        metadata={
            "name": "PersonalNameSubject",
            "type": "Element",
            "min_occurs": 1,
        }
    )



from enum import Enum


class UrlLang(Enum):
    AF = "AF"
    AR = "AR"
    AZ = "AZ"
    BG = "BG"
    CS = "CS"
    DA = "DA"
    DE = "DE"
    EN = "EN"
    EL = "EL"
    ES = "ES"
    FA = "FA"
    FI = "FI"
    FR = "FR"
    HE = "HE"
    HU = "HU"
    HY = "HY"
    IN = "IN"
    IS = "IS"
    IT = "IT"
    IW = "IW"
    JA = "JA"
    KA = "KA"
    KO = "KO"
    LT = "LT"
    MK = "MK"
    ML = "ML"
    NL = "NL"
    NO = "NO"
    PL = "PL"
    PT = "PT"
    PS = "PS"
    RO = "RO"
    RU = "RU"
    SL = "SL"
    SK = "SK"
    SQ = "SQ"
    SR = "SR"
    SV = "SV"
    SW = "SW"
    TH = "TH"
    TR = "TR"
    UK = "UK"
    VI = "VI"
    ZH = "ZH"



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .author import Author
from .author_list_complete_yn import AuthorListCompleteYn
from .author_list_type import AuthorListType


@dataclass
class AuthorList:
    complete_yn: AuthorListCompleteYn = field(
        default=AuthorListCompleteYn.Y,
        metadata={
            "name": "CompleteYN",
            "type": "Attribute",
            "required": True,
        }
    )
    type: Optional[AuthorListType] = field(
        default=None,
        metadata={
            "name": "Type",
            "type": "Attribute",
        }
    )
    author: List[Author] = field(
        default_factory=list,
        metadata={
            "name": "Author",
            "type": "Element",
            "min_occurs": 1,
        }
    )



from enum import Enum

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


class MscarryValue(Enum):
    NONE = "none"
    UPDIAGONALSTRIKE = "updiagonalstrike"
    DOWNDIAGONALSTRIKE = "downdiagonalstrike"
    VERTICALSTRIKE = "verticalstrike"
    HORIZONTALSTRIKE = "horizontalstrike"



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional
from .name_of_substance import NameOfSubstance


@dataclass
class Chemical:
    registry_number: Optional[str] = field(
        default=None,
        metadata={
            "name": "RegistryNumber",
            "type": "Element",
            "required": True,
        }
    )
    name_of_substance: Optional[NameOfSubstance] = field(
        default=None,
        metadata={
            "name": "NameOfSubstance",
            "type": "Element",
            "required": True,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .reference import Reference


@dataclass
class ReferenceList:
    title: Optional[str] = field(
        default=None,
        metadata={
            "name": "Title",
            "type": "Element",
        }
    )
    reference: List[Reference] = field(
        default_factory=list,
        metadata={
            "name": "Reference",
            "type": "Element",
        }
    )
    reference_list: List["ReferenceList"] = field(
        default_factory=list,
        metadata={
            "name": "ReferenceList",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional, Union
from .access_date import (
    Date,
    Email,
    ExtLink,
    Isbn,
    Issn,
    IssnL,
    StringDate,
    Uri,
)
from .article_id import ArticleId
from .article_version import ArticleVersion
from .article_version_alternatives import ArticleVersionAlternatives
from .org.w3.xml.pkg_1998.namespace.lang_value import LangValue
from .pub_date_2 import PubDate2
from .pub_date_not_available import PubDateNotAvailable


@dataclass
class EventDesc:
    """
    <div> <h3>Event Description</h3> </div>
    """
    class Meta:
        name = "event-desc"

    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    specific_use: Optional[str] = field(
        default=None,
        metadata={
            "name": "specific-use",
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    lang: Optional[Union[str, LangValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    content: List[object] = field(
        default_factory=list,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
            "mixed": True,
            "choices": (
                {
                    "name": "email",
                    "type": Email,
                },
                {
                    "name": "ext-link",
                    "type": ExtLink,
                },
                {
                    "name": "uri",
                    "type": Uri,
                },
                {
                    "name": "article-id",
                    "type": ArticleId,
                },
                {
                    "name": "issn",
                    "type": Issn,
                },
                {
                    "name": "issn-l",
                    "type": IssnL,
                },
                {
                    "name": "isbn",
                    "type": Isbn,
                },
                {
                    "name": "article-version",
                    "type": ArticleVersion,
                },
                {
                    "name": "article-version-alternatives",
                    "type": ArticleVersionAlternatives,
                },
                {
                    "name": "date",
                    "type": Date,
                },
                {
                    "name": "string-date",
                    "type": StringDate,
                },
                {
                    "name": "pub-date",
                    "type": PubDate2,
                },
                {
                    "name": "pub-date-not-available",
                    "type": PubDateNotAvailable,
                },
            ),
        }
    )



from enum import Enum


class OtherIdSource(Enum):
    NASA = "NASA"
    KIE = "KIE"
    PIP = "PIP"
    POP = "POP"
    ARPL = "ARPL"
    CPC = "CPC"
    IND = "IND"
    CPFH = "CPFH"
    CLML = "CLML"
    NRCBL = "NRCBL"
    NLM = "NLM"
    QCIM = "QCIM"



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .affiliation_info import AffiliationInfo
from .author_equal_contrib import AuthorEqualContrib
from .author_valid_yn import AuthorValidYn
from .collective_name import CollectiveName
from .identifier import Identifier
from .suffix_1 import Suffix1


@dataclass
class Author:
    valid_yn: AuthorValidYn = field(
        default=AuthorValidYn.Y,
        metadata={
            "name": "ValidYN",
            "type": "Attribute",
            "required": True,
        }
    )
    equal_contrib: Optional[AuthorEqualContrib] = field(
        default=None,
        metadata={
            "name": "EqualContrib",
            "type": "Attribute",
        }
    )
    last_name: Optional[str] = field(
        default=None,
        metadata={
            "name": "LastName",
            "type": "Element",
        }
    )
    fore_name: Optional[str] = field(
        default=None,
        metadata={
            "name": "ForeName",
            "type": "Element",
        }
    )
    initials: Optional[str] = field(
        default=None,
        metadata={
            "name": "Initials",
            "type": "Element",
        }
    )
    suffix: Optional[Suffix1] = field(
        default=None,
        metadata={
            "name": "Suffix",
            "type": "Element",
        }
    )
    collective_name: Optional[CollectiveName] = field(
        default=None,
        metadata={
            "name": "CollectiveName",
            "type": "Element",
        }
    )
    identifier: List[Identifier] = field(
        default_factory=list,
        metadata={
            "name": "Identifier",
            "type": "Element",
        }
    )
    affiliation_info: List[AffiliationInfo] = field(
        default_factory=list,
        metadata={
            "name": "AffiliationInfo",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .abstract_1 import Abstract1
from .article_id_list import ArticleIdList
from .article_title_1 import ArticleTitle1
from .author_list import AuthorList
from .book import Book
from .contribution_date import ContributionDate
from .date_revised import DateRevised
from .grant_list import GrantList
from .investigator_list import InvestigatorList
from .item_list import ItemList
from .keyword_list import KeywordList
from .location_label import LocationLabel
from .pagination import Pagination
from .pmid import Pmid
from .publication_type import PublicationType
from .reference_list import ReferenceList
from .sections import Sections
from .vernacular_title import VernacularTitle


@dataclass
class BookDocument:
    pmid: Optional[Pmid] = field(
        default=None,
        metadata={
            "name": "PMID",
            "type": "Element",
            "required": True,
        }
    )
    article_id_list: Optional[ArticleIdList] = field(
        default=None,
        metadata={
            "name": "ArticleIdList",
            "type": "Element",
            "required": True,
        }
    )
    book: Optional[Book] = field(
        default=None,
        metadata={
            "name": "Book",
            "type": "Element",
            "required": True,
        }
    )
    location_label: List[LocationLabel] = field(
        default_factory=list,
        metadata={
            "name": "LocationLabel",
            "type": "Element",
        }
    )
    article_title: Optional[ArticleTitle1] = field(
        default=None,
        metadata={
            "name": "ArticleTitle",
            "type": "Element",
        }
    )
    vernacular_title: Optional[VernacularTitle] = field(
        default=None,
        metadata={
            "name": "VernacularTitle",
            "type": "Element",
        }
    )
    pagination: Optional[Pagination] = field(
        default=None,
        metadata={
            "name": "Pagination",
            "type": "Element",
        }
    )
    language: List[str] = field(
        default_factory=list,
        metadata={
            "name": "Language",
            "type": "Element",
        }
    )
    author_list: List[AuthorList] = field(
        default_factory=list,
        metadata={
            "name": "AuthorList",
            "type": "Element",
        }
    )
    investigator_list: Optional[InvestigatorList] = field(
        default=None,
        metadata={
            "name": "InvestigatorList",
            "type": "Element",
        }
    )
    publication_type: List[PublicationType] = field(
        default_factory=list,
        metadata={
            "name": "PublicationType",
            "type": "Element",
        }
    )
    abstract: Optional[Abstract1] = field(
        default=None,
        metadata={
            "name": "Abstract",
            "type": "Element",
        }
    )
    sections: Optional[Sections] = field(
        default=None,
        metadata={
            "name": "Sections",
            "type": "Element",
        }
    )
    keyword_list: List[KeywordList] = field(
        default_factory=list,
        metadata={
            "name": "KeywordList",
            "type": "Element",
        }
    )
    contribution_date: Optional[ContributionDate] = field(
        default=None,
        metadata={
            "name": "ContributionDate",
            "type": "Element",
        }
    )
    date_revised: Optional[DateRevised] = field(
        default=None,
        metadata={
            "name": "DateRevised",
            "type": "Element",
        }
    )
    grant_list: Optional[GrantList] = field(
        default=None,
        metadata={
            "name": "GrantList",
            "type": "Element",
        }
    )
    item_list: List[ItemList] = field(
        default_factory=list,
        metadata={
            "name": "ItemList",
            "type": "Element",
        }
    )
    reference_list: List[ReferenceList] = field(
        default_factory=list,
        metadata={
            "name": "ReferenceList",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional
from .url_lang import UrlLang
from .url_type import UrlType


@dataclass
class Url:
    class Meta:
        name = "URL"

    lang: Optional[UrlLang] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    type: Optional[UrlType] = field(
        default=None,
        metadata={
            "name": "Type",
            "type": "Attribute",
        }
    )
    value: str = field(
        default="",
        metadata={
            "required": True,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional
from .issn_issn_type import IssnIssnType


@dataclass
class Issn1:
    class Meta:
        name = "ISSN"

    issn_type: Optional[IssnIssnType] = field(
        default=None,
        metadata={
            "name": "IssnType",
            "type": "Attribute",
            "required": True,
        }
    )
    value: str = field(
        default="",
        metadata={
            "required": True,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .org.w3.xml.pkg_1998.namespace.space_value import SpaceValue


@dataclass
class GlyphData:
    """
    <div> <h3>Glyph Data For a Private Character</h3> </div>
    """
    class Meta:
        name = "glyph-data"

    fontchar: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    fontname: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    format: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    resolution: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    x_size: Optional[str] = field(
        default=None,
        metadata={
            "name": "x-size",
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    space: SpaceValue = field(
        init=False,
        default=SpaceValue.PRESERVE,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    y_size: Optional[str] = field(
        default=None,
        metadata={
            "name": "y-size",
            "type": "Attribute",
        }
    )
    content: List[object] = field(
        default_factory=list,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
            "mixed": True,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional, Union
from .access_date import (
    Ack,
    Address,
    Alternatives,
    Answer,
    AnswerSet,
    Array,
    BlockAlternatives,
    BoxedText,
    ChemStructWrap,
    Code,
    DefList,
    DispFormulaGroup,
    DispFormula2,
    DispQuote,
    Explanation,
    Fig,
    FigGroup,
    FnGroup,
    Glossary,
    Graphic,
    Label,
    ListType,
    Media,
    Notes,
    P,
    Permissions,
    Preformat,
    Question,
    QuestionWrap,
    QuestionWrapGroup,
    RefList,
    RelatedArticle,
    RelatedObject,
    Sec,
    SecMeta,
    Speech,
    Statement,
    SupplementaryMaterial,
    TableWrap,
    TableWrapGroup,
    Title,
    VerseGroup,
    X,
)
from .org.w3.pkg_1998.math.math_ml.math import Math
from .org.w3.xml.pkg_1998.namespace.lang_value import LangValue
from .tex_math import TexMath


@dataclass
class App:
    """
    <div> <h3>Appendix</h3> </div>
    """
    class Meta:
        name = "app"

    sec_meta: Optional[SecMeta] = field(
        default=None,
        metadata={
            "name": "sec-meta",
            "type": "Element",
        }
    )
    label: Optional[Label] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    title: Optional[Title] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    address: List[Address] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    alternatives: List[Alternatives] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    answer: List[Answer] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    answer_set: List[AnswerSet] = field(
        default_factory=list,
        metadata={
            "name": "answer-set",
            "type": "Element",
        }
    )
    array: List[Array] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    block_alternatives: List[BlockAlternatives] = field(
        default_factory=list,
        metadata={
            "name": "block-alternatives",
            "type": "Element",
        }
    )
    boxed_text: List[BoxedText] = field(
        default_factory=list,
        metadata={
            "name": "boxed-text",
            "type": "Element",
        }
    )
    chem_struct_wrap: List[ChemStructWrap] = field(
        default_factory=list,
        metadata={
            "name": "chem-struct-wrap",
            "type": "Element",
        }
    )
    code: List[Code] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    explanation: List[Explanation] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fig: List[Fig] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fig_group: List[FigGroup] = field(
        default_factory=list,
        metadata={
            "name": "fig-group",
            "type": "Element",
        }
    )
    graphic: List[Graphic] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    media: List[Media] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    preformat: List[Preformat] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    question: List[Question] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    question_wrap: List[QuestionWrap] = field(
        default_factory=list,
        metadata={
            "name": "question-wrap",
            "type": "Element",
        }
    )
    question_wrap_group: List[QuestionWrapGroup] = field(
        default_factory=list,
        metadata={
            "name": "question-wrap-group",
            "type": "Element",
        }
    )
    supplementary_material: List[SupplementaryMaterial] = field(
        default_factory=list,
        metadata={
            "name": "supplementary-material",
            "type": "Element",
        }
    )
    table_wrap: List[TableWrap] = field(
        default_factory=list,
        metadata={
            "name": "table-wrap",
            "type": "Element",
        }
    )
    table_wrap_group: List[TableWrapGroup] = field(
        default_factory=list,
        metadata={
            "name": "table-wrap-group",
            "type": "Element",
        }
    )
    disp_formula: List[DispFormula2] = field(
        default_factory=list,
        metadata={
            "name": "disp-formula",
            "type": "Element",
        }
    )
    disp_formula_group: List[DispFormulaGroup] = field(
        default_factory=list,
        metadata={
            "name": "disp-formula-group",
            "type": "Element",
        }
    )
    def_list: List[DefList] = field(
        default_factory=list,
        metadata={
            "name": "def-list",
            "type": "Element",
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    tex_math: List[TexMath] = field(
        default_factory=list,
        metadata={
            "name": "tex-math",
            "type": "Element",
        }
    )
    math: List[Math] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    p: List[P] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    related_article: List[RelatedArticle] = field(
        default_factory=list,
        metadata={
            "name": "related-article",
            "type": "Element",
        }
    )
    related_object: List[RelatedObject] = field(
        default_factory=list,
        metadata={
            "name": "related-object",
            "type": "Element",
        }
    )
    ack: List[Ack] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    disp_quote: List[DispQuote] = field(
        default_factory=list,
        metadata={
            "name": "disp-quote",
            "type": "Element",
        }
    )
    speech: List[Speech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    statement: List[Statement] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    verse_group: List[VerseGroup] = field(
        default_factory=list,
        metadata={
            "name": "verse-group",
            "type": "Element",
        }
    )
    x: List[X] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notes: List[Notes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fn_group: List[FnGroup] = field(
        default_factory=list,
        metadata={
            "name": "fn-group",
            "type": "Element",
        }
    )
    glossary: List[Glossary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ref_list: List[RefList] = field(
        default_factory=list,
        metadata={
            "name": "ref-list",
            "type": "Element",
        }
    )
    permissions: Optional[Permissions] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    content_type: Optional[str] = field(
        default=None,
        metadata={
            "name": "content-type",
            "type": "Attribute",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    specific_use: Optional[str] = field(
        default=None,
        metadata={
            "name": "specific-use",
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    lang: Optional[Union[str, LangValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .access_date import SubjGroup
from .series_text import SeriesText
from .series_title import SeriesTitle


@dataclass
class ArticleCategories:
    """
    <div> <h3>Article Grouping Data</h3> </div>
    """
    class Meta:
        name = "article-categories"

    subj_group: List[SubjGroup] = field(
        default_factory=list,
        metadata={
            "name": "subj-group",
            "type": "Element",
        }
    )
    series_title: List[SeriesTitle] = field(
        default_factory=list,
        metadata={
            "name": "series-title",
            "type": "Element",
        }
    )
    series_text: List[SeriesText] = field(
        default_factory=list,
        metadata={
            "name": "series-text",
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List
from .mesh_heading import MeshHeading


@dataclass
class MeshHeadingList:
    mesh_heading: List[MeshHeading] = field(
        default_factory=list,
        metadata={
            "name": "MeshHeading",
            "type": "Element",
            "min_occurs": 1,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional


@dataclass
class Pagination:
    start_page: Optional[str] = field(
        default=None,
        metadata={
            "name": "StartPage",
            "type": "Element",
        }
    )
    end_page: Optional[str] = field(
        default=None,
        metadata={
            "name": "EndPage",
            "type": "Element",
        }
    )
    medline_pgn: List[str] = field(
        default_factory=list,
        metadata={
            "name": "MedlinePgn",
            "type": "Element",
            "max_occurs": 2,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .delete_citation import DeleteCitation
from .pubmed_article import PubmedArticle
from .pubmed_book_article import PubmedBookArticle


@dataclass
class PubmedArticleSet:
    pubmed_article: List[PubmedArticle] = field(
        default_factory=list,
        metadata={
            "name": "PubmedArticle",
            "type": "Element",
        }
    )
    pubmed_book_article: List[PubmedBookArticle] = field(
        default_factory=list,
        metadata={
            "name": "PubmedBookArticle",
            "type": "Element",
        }
    )
    delete_citation: Optional[DeleteCitation] = field(
        default=None,
        metadata={
            "name": "DeleteCitation",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional
from .publisher_name_1 import PublisherName1


@dataclass
class Publisher1:
    class Meta:
        name = "Publisher"

    publisher_name: Optional[PublisherName1] = field(
        default=None,
        metadata={
            "name": "PublisherName",
            "type": "Element",
            "required": True,
        }
    )
    publisher_location: Optional[str] = field(
        default=None,
        metadata={
            "name": "PublisherLocation",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional, Union
from .type_value import TypeValue
from ...xml.pkg_1998.namespace.lang_value import LangValue

__NAMESPACE__ = "http://www.w3.org/1999/xlink"


@dataclass
class TitleEltType:
    """
    :ivar type:
    :ivar lang: xml:lang is not required, but provides much of the
        motivation for title elements in addition to attributes, and so
        is provided here for convenience.
    :ivar content:
    """
    class Meta:
        name = "titleEltType"

    type: TypeValue = field(
        init=False,
        default=TypeValue.TITLE,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
            "required": True,
        }
    )
    lang: Optional[Union[str, LangValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    content: List[object] = field(
        default_factory=list,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
            "mixed": True,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional, Union
from .access_date import (
    Abbrev,
    Alternatives,
    Bold,
    ChemStruct,
    Email,
    ExtLink,
    FixedCase,
    Fn,
    IndexTerm,
    InlineFormula,
    InlineGraphic,
    InlineMedia,
    InlineSupplementaryMaterial,
    Italic,
    Monospace,
    NamedContent,
    Overline,
    PrivateChar,
    RelatedArticle,
    RelatedObject,
    Roman,
    Ruby,
    SansSerif,
    Sc,
    Strike,
    StyledContent,
    Sub,
    Sup,
    Target,
    Underline,
    Uri,
    X,
    Xref,
)
from .hr import Hr
from .index_term_range_end import IndexTermRangeEnd
from .milestone_end import MilestoneEnd
from .milestone_start import MilestoneStart
from .org.w3.pkg_1998.math.math_ml.math import Math
from .org.w3.xml.pkg_1998.namespace.lang_value import LangValue
from .overline_end import OverlineEnd
from .overline_start import OverlineStart
from .tex_math import TexMath
from .underline_end import UnderlineEnd
from .underline_start import UnderlineStart


@dataclass
class JournalSubtitle:
    """
    <div> <h3>Journal Subtitle</h3> </div>
    """
    class Meta:
        name = "journal-subtitle"

    content_type: Optional[str] = field(
        default=None,
        metadata={
            "name": "content-type",
            "type": "Attribute",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    specific_use: Optional[str] = field(
        default=None,
        metadata={
            "name": "specific-use",
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    lang: Optional[Union[str, LangValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    content: List[object] = field(
        default_factory=list,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
            "mixed": True,
            "choices": (
                {
                    "name": "email",
                    "type": Email,
                },
                {
                    "name": "ext-link",
                    "type": ExtLink,
                },
                {
                    "name": "uri",
                    "type": Uri,
                },
                {
                    "name": "inline-supplementary-material",
                    "type": InlineSupplementaryMaterial,
                },
                {
                    "name": "related-article",
                    "type": RelatedArticle,
                },
                {
                    "name": "related-object",
                    "type": RelatedObject,
                },
                {
                    "name": "hr",
                    "type": Hr,
                },
                {
                    "name": "bold",
                    "type": Bold,
                },
                {
                    "name": "fixed-case",
                    "type": FixedCase,
                },
                {
                    "name": "italic",
                    "type": Italic,
                },
                {
                    "name": "monospace",
                    "type": Monospace,
                },
                {
                    "name": "overline",
                    "type": Overline,
                },
                {
                    "name": "overline-start",
                    "type": OverlineStart,
                },
                {
                    "name": "overline-end",
                    "type": OverlineEnd,
                },
                {
                    "name": "roman",
                    "type": Roman,
                },
                {
                    "name": "sans-serif",
                    "type": SansSerif,
                },
                {
                    "name": "sc",
                    "type": Sc,
                },
                {
                    "name": "strike",
                    "type": Strike,
                },
                {
                    "name": "underline",
                    "type": Underline,
                },
                {
                    "name": "underline-start",
                    "type": UnderlineStart,
                },
                {
                    "name": "underline-end",
                    "type": UnderlineEnd,
                },
                {
                    "name": "ruby",
                    "type": Ruby,
                },
                {
                    "name": "alternatives",
                    "type": Alternatives,
                },
                {
                    "name": "inline-graphic",
                    "type": InlineGraphic,
                },
                {
                    "name": "inline-media",
                    "type": InlineMedia,
                },
                {
                    "name": "private-char",
                    "type": PrivateChar,
                },
                {
                    "name": "chem-struct",
                    "type": ChemStruct,
                },
                {
                    "name": "inline-formula",
                    "type": InlineFormula,
                },
                {
                    "name": "tex-math",
                    "type": TexMath,
                },
                {
                    "name": "math",
                    "type": Math,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "abbrev",
                    "type": Abbrev,
                },
                {
                    "name": "index-term",
                    "type": IndexTerm,
                },
                {
                    "name": "index-term-range-end",
                    "type": IndexTermRangeEnd,
                },
                {
                    "name": "milestone-end",
                    "type": MilestoneEnd,
                },
                {
                    "name": "milestone-start",
                    "type": MilestoneStart,
                },
                {
                    "name": "named-content",
                    "type": NamedContent,
                },
                {
                    "name": "styled-content",
                    "type": StyledContent,
                },
                {
                    "name": "fn",
                    "type": Fn,
                },
                {
                    "name": "target",
                    "type": Target,
                },
                {
                    "name": "xref",
                    "type": Xref,
                },
                {
                    "name": "sub",
                    "type": Sub,
                },
                {
                    "name": "sup",
                    "type": Sup,
                },
                {
                    "name": "x",
                    "type": X,
                },
            ),
        }
    )



from enum import Enum

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


class MspaceLinebreak(Enum):
    AUTO = "auto"
    NEWLINE = "newline"
    NOBREAK = "nobreak"
    GOODBREAK = "goodbreak"
    BADBREAK = "badbreak"
    INDENTINGNEWLINE = "indentingnewline"



from enum import Enum


class LocationLabelType(Enum):
    PART = "part"
    CHAPTER = "chapter"
    SECTION = "section"
    APPENDIX = "appendix"
    FIGURE = "figure"
    TABLE = "table"
    BOX = "box"



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional


@dataclass
class WordCount:
    """
    <div> <h3>Word Count</h3> </div>
    """
    class Meta:
        name = "word-count"

    count: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "required": True,
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional


@dataclass
class DispFormula1:
    class Meta:
        name = "DispFormula"

    math: Optional[str] = field(
        default=None,
        metadata={
            "type": "Element",
            "required": True,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional
from .comments_corrections_ref_type import CommentsCorrectionsRefType
from .pmid import Pmid


@dataclass
class CommentsCorrections:
    ref_type: Optional[CommentsCorrectionsRefType] = field(
        default=None,
        metadata={
            "name": "RefType",
            "type": "Attribute",
            "required": True,
        }
    )
    ref_source: Optional[str] = field(
        default=None,
        metadata={
            "name": "RefSource",
            "type": "Element",
            "required": True,
        }
    )
    pmid: Optional[Pmid] = field(
        default=None,
        metadata={
            "name": "PMID",
            "type": "Element",
        }
    )
    note: Optional[str] = field(
        default=None,
        metadata={
            "name": "Note",
            "type": "Element",
        }
    )



from enum import Enum


class ArticleIdIdType(Enum):
    DOI = "doi"
    PII = "pii"
    PMCPID = "pmcpid"
    PMPID = "pmpid"
    PMC = "pmc"
    MID = "mid"
    SICI = "sici"
    PUBMED = "pubmed"
    MEDLINE = "medline"
    PMCID = "pmcid"
    PMCBOOK = "pmcbook"
    BOOKACCESSION = "bookaccession"



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional
from .actuate_value import ActuateValue
from .show_value import ShowValue
from .type_value import TypeValue

__NAMESPACE__ = "http://www.w3.org/1999/xlink"


@dataclass
class ArcType:
    """
    :ivar type:
    :ivar arcrole:
    :ivar title:
    :ivar show:
    :ivar actuate:
    :ivar from_value:
    :ivar to: from and to have default behavior when values are missing
    """
    class Meta:
        name = "arcType"

    type: TypeValue = field(
        init=False,
        default=TypeValue.ARC,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
            "required": True,
        }
    )
    arcrole: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    title: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    show: Optional[ShowValue] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    actuate: Optional[ActuateValue] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    from_value: Optional[str] = field(
        default=None,
        metadata={
            "name": "from",
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    to: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .author_list import AuthorList
from .beginning_date import BeginningDate
from .book_title import BookTitle
from .collection_title import CollectionTitle
from .elocation_id_1 import ElocationId1
from .ending_date import EndingDate
from .investigator_list import InvestigatorList
from .pub_date_1 import PubDate1
from .publisher_1 import Publisher1
from .volume_title import VolumeTitle


@dataclass
class Book:
    publisher: Optional[Publisher1] = field(
        default=None,
        metadata={
            "name": "Publisher",
            "type": "Element",
            "required": True,
        }
    )
    book_title: Optional[BookTitle] = field(
        default=None,
        metadata={
            "name": "BookTitle",
            "type": "Element",
            "required": True,
        }
    )
    pub_date: Optional[PubDate1] = field(
        default=None,
        metadata={
            "name": "PubDate",
            "type": "Element",
            "required": True,
        }
    )
    beginning_date: Optional[BeginningDate] = field(
        default=None,
        metadata={
            "name": "BeginningDate",
            "type": "Element",
        }
    )
    ending_date: Optional[EndingDate] = field(
        default=None,
        metadata={
            "name": "EndingDate",
            "type": "Element",
        }
    )
    author_list: List[AuthorList] = field(
        default_factory=list,
        metadata={
            "name": "AuthorList",
            "type": "Element",
        }
    )
    investigator_list: Optional[InvestigatorList] = field(
        default=None,
        metadata={
            "name": "InvestigatorList",
            "type": "Element",
        }
    )
    volume: Optional[str] = field(
        default=None,
        metadata={
            "name": "Volume",
            "type": "Element",
        }
    )
    volume_title: Optional[VolumeTitle] = field(
        default=None,
        metadata={
            "name": "VolumeTitle",
            "type": "Element",
        }
    )
    edition: Optional[str] = field(
        default=None,
        metadata={
            "name": "Edition",
            "type": "Element",
        }
    )
    collection_title: Optional[CollectionTitle] = field(
        default=None,
        metadata={
            "name": "CollectionTitle",
            "type": "Element",
        }
    )
    isbn: List[str] = field(
        default_factory=list,
        metadata={
            "name": "Isbn",
            "type": "Element",
        }
    )
    elocation_id: List[ElocationId1] = field(
        default_factory=list,
        metadata={
            "name": "ELocationID",
            "type": "Element",
        }
    )
    medium: Optional[str] = field(
        default=None,
        metadata={
            "name": "Medium",
            "type": "Element",
        }
    )
    report_number: Optional[str] = field(
        default=None,
        metadata={
            "name": "ReportNumber",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional
from .pub_med_pub_date_pub_status import PubMedPubDatePubStatus


@dataclass
class PubMedPubDate:
    pub_status: Optional[PubMedPubDatePubStatus] = field(
        default=None,
        metadata={
            "name": "PubStatus",
            "type": "Attribute",
            "required": True,
        }
    )
    year: Optional[str] = field(
        default=None,
        metadata={
            "name": "Year",
            "type": "Element",
            "required": True,
        }
    )
    month: Optional[str] = field(
        default=None,
        metadata={
            "name": "Month",
            "type": "Element",
            "required": True,
        }
    )
    day: Optional[str] = field(
        default=None,
        metadata={
            "name": "Day",
            "type": "Element",
            "required": True,
        }
    )
    hour: Optional[str] = field(
        default=None,
        metadata={
            "name": "Hour",
            "type": "Element",
            "required": True,
        }
    )
    minute: Optional[str] = field(
        default=None,
        metadata={
            "name": "Minute",
            "type": "Element",
            "required": True,
        }
    )
    second: Optional[str] = field(
        default=None,
        metadata={
            "name": "Second",
            "type": "Element",
        }
    )



from enum import Enum


class ArticlePubModel(Enum):
    PRINT = "Print"
    PRINT_ELECTRONIC = "Print-Electronic"
    ELECTRONIC = "Electronic"
    ELECTRONIC_PRINT = "Electronic-Print"
    ELECTRONIC_E_COLLECTION = "Electronic-eCollection"



from enum import Enum

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


class MathLinebreakstyle(Enum):
    BEFORE = "before"
    AFTER = "after"
    DUPLICATE = "duplicate"
    INFIXLINEBREAKSTYLE = "infixlinebreakstyle"
